Structs
- Graph
Builder - Builder for constructing the audio processing graph.
- NodeId
- A unique identifier for a node in the audio graph.
- Static
Graph - Fully static, zero-allocation audio runtime core
Enums
- Control
Message - Commands sent to the audio thread to update node parameters.
- Node
Parameter - Generic parameter, supporting dynamic updates of node properties.