pub struct OscillatorNode { /* private fields */ }Expand description
An audio source that generates periodic waveforms.
Currently, it generates a sine wave at the specified frequency. It runs a background thread to generate samples and uses a ring buffer to communicate with the audio processing thread.
Implementations