pub struct RingIter {
pub consumer: Caching<Arc<SharedRb<Heap<f32>>>, false, true>,
pub channels: usize,
}Fields
consumer: Caching<Arc<SharedRb<Heap<f32>>>, false, true>channels: usizeTrait Implementations
Sourceimpl Signal for RingIter
impl Signal for RingIter
Sourcefn is_exhausted(&self) -> bool
fn is_exhausted(&self) -> bool
Whether or not the signal is exhausted of meaningful frames. Read more
Sourcefn map<M, F>(self, map: M) -> Map<Self, M, F>
fn map<M, F>(self, map: M) -> Map<Self, M, F>
A signal that maps one set of frames to another. Read more
Sourcefn zip_map<O, M, F>(self, other: O, map: M) -> ZipMap<Self, O, M, F>
fn zip_map<O, M, F>(self, other: O, map: M) -> ZipMap<Self, O, M, F>
A signal that maps one set of frames to another. Read more
Sourcefn add_amp<S>(self, other: S) -> AddAmp<Self, S>
fn add_amp<S>(self, other: S) -> AddAmp<Self, S>
Provides an iterator that yields the sum of the frames yielded by both
other and self
in lock-step. Read moreSourcefn mul_amp<S>(self, other: S) -> MulAmp<Self, S>
fn mul_amp<S>(self, other: S) -> MulAmp<Self, S>
Provides an iterator that yields the product of the frames yielded by both
other and
self in lock-step. Read moreSourcefn offset_amp(
self,
offset: <<Self::Frame as Frame>::Sample as Sample>::Signed,
) -> OffsetAmp<Self>where
Self: Sized,
fn offset_amp(
self,
offset: <<Self::Frame as Frame>::Sample as Sample>::Signed,
) -> OffsetAmp<Self>where
Self: Sized,
Provides an iterator that offsets the amplitude of every channel in each frame of the
signal by some sample value and yields the resulting frames. Read more
Sourcefn scale_amp(
self,
amp: <<Self::Frame as Frame>::Sample as Sample>::Float,
) -> ScaleAmp<Self>where
Self: Sized,
fn scale_amp(
self,
amp: <<Self::Frame as Frame>::Sample as Sample>::Float,
) -> ScaleAmp<Self>where
Self: Sized,
Produces an
Iterator that scales the amplitude of the sample of each channel in every
Frame yielded by self by the given amplitude. Read moreSourcefn offset_amp_per_channel<F>(self, amp_frame: F) -> OffsetAmpPerChannel<Self, F>
fn offset_amp_per_channel<F>(self, amp_frame: F) -> OffsetAmpPerChannel<Self, F>
Produces a new
Signal that offsets the amplitude of every Frame in self by the
respective amplitudes in each channel of the given amp_frame. Read moreSourcefn scale_amp_per_channel<F>(self, amp_frame: F) -> ScaleAmpPerChannel<Self, F>
fn scale_amp_per_channel<F>(self, amp_frame: F) -> ScaleAmpPerChannel<Self, F>
Produces a new
Signal that scales the amplitude of every Frame in self by the
respective amplitudes in each channel of the given amp_frame. Read moreSourcefn from_hz_to_hz<I>(
self,
interpolator: I,
source_hz: f64,
target_hz: f64,
) -> Converter<Self, I>where
Self: Sized,
I: Interpolator,
fn from_hz_to_hz<I>(
self,
interpolator: I,
source_hz: f64,
target_hz: f64,
) -> Converter<Self, I>where
Self: Sized,
I: Interpolator,
Converts the rate at which frames of the
Signal are yielded using interpolation. Read moreSourcefn scale_hz<I>(self, interpolator: I, multi: f64) -> Converter<Self, I>where
Self: Sized,
I: Interpolator,
fn scale_hz<I>(self, interpolator: I, multi: f64) -> Converter<Self, I>where
Self: Sized,
I: Interpolator,
Multiplies the rate at which frames of the
Signal are yielded by the given value. Read moreSourcefn delay(self, n_frames: usize) -> Delay<Self>where
Self: Sized,
fn delay(self, n_frames: usize) -> Delay<Self>where
Self: Sized,
Delays the
Signal by the given number of frames. Read moreSourcefn into_interleaved_samples(self) -> IntoInterleavedSamples<Self>where
Self: Sized,
fn into_interleaved_samples(self) -> IntoInterleavedSamples<Self>where
Self: Sized,
Sourcefn clip_amp(
self,
thresh: <<Self::Frame as Frame>::Sample as Sample>::Signed,
) -> ClipAmp<Self>where
Self: Sized,
fn clip_amp(
self,
thresh: <<Self::Frame as Frame>::Sample as Sample>::Signed,
) -> ClipAmp<Self>where
Self: Sized,
Clips the amplitude of each channel in each
Frame yielded by self to the given
threshold amplitude. Read moreSourcefn inspect<F>(self, inspect: F) -> Inspect<Self, F>
fn inspect<F>(self, inspect: F) -> Inspect<Self, F>
Create a new
Signal that calls the enclosing function on each iteration. Read moreSourcefn fork<S>(self, ring_buffer: Bounded<S>) -> Fork<Self, S>
fn fork<S>(self, ring_buffer: Bounded<S>) -> Fork<Self, S>
Forks
Self into two signals that produce the same frames. Read moreSourcefn take(self, n: usize) -> Take<Self>where
Self: Sized,
fn take(self, n: usize) -> Take<Self>where
Self: Sized,
Converts the
Signal into an Iterator that will yield the given number for Frames
before returning None. Read moreSourcefn until_exhausted(self) -> UntilExhausted<Self>where
Self: Sized,
fn until_exhausted(self) -> UntilExhausted<Self>where
Self: Sized,
Converts the
Signal into an Iterator yielding frames until the signal.is_exhausted()
returns true. Read moreAuto Trait Implementations
impl !Freeze for RingIter
impl !RefUnwindSafe for RingIter
impl Send for RingIter
impl !Sync for RingIter
impl Unpin for RingIter
impl UnsafeUnpin for RingIter
impl UnwindSafe for RingIter